#!/bin/bash
# Encoding: UTF-8 (Unicode)
# :set syntax=sh

#===========================================================================
# Copyright ©MMXX - J. S. Gilstrap - JSG™
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 3 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Any knowledge gained by viewing and/or using this software may NOT be used
# to file for any 'submarine' patents on applicable algorithmns and/or ideas
# or any other method that would undermine the free use and/or distribution
# thereof. By viewing and/or using this software you agree to these terms.
# If you cannot agree to this then do NOT view and/or use this software.
#===========================================================================

# Dorothy Foot Calculator

# Display help.
if [ "$1" = --help ]
then
	echo
	echo "[1m	       EU Dorothy Foot Calculator X[0m"
	echo      "	Usage: dorothyx.sh [-e text editor ] [ output filename ]"
	echo
	exit 1
fi

# Text Editors
EDITORS="vi vim gvim emacs pico nano gedit kedit kate oowriter"

# ANSI Color Formatting
Mx="[30;42mM[47me[41mx[0m"        ; UK="[1;38;5;129mUK[0m" ; US="[1;34mU[31mS[0m"
usM="[1;34mu[31ms[32mM[0m"        ; eXp6="[1meXp[34m6[30m™[0m" ; eXp5="[1meXp[32m5[30m™[0m"
usW="[1;34mu[31ms[38;5;124mW[0m"  ; eXp7="[1meXp[38;5;129m7[30m™[0m"
BR="[1;48;5;40;38;5;21m B[33mR [0m" ; ITEU="[1;31mI[32mT[0m/[1;33;44mEU[0m" ; FR="[37;44mF[47m [41mR[0m"
# Uncomment for no color.
#Mx="[1mMex[0m" ; UK="[1mUK[0m" ; usM="[1musM[0m" ; usW="[1musW[0m" ; BR=" [1mBR[0m " ; ITEU="[1mIT|EU[0m" ; FR="[1mFR[0m " usM="[1musM[0m" ; usW="[1musW[0m"

# Display message.
cat <<End

	[1;107;91mEU Dorothy Foot Calculator X[0m

Set Terminal Geometry to 84×40 minimum.

Paris Point to Barleycorn Last conversion accuracy is
within ±½mm from sizes usW 5 to usM 11 (UK 2½ to 10)
[Mx|UK|usM|usW] = IT|EU ÷ 1¼ ─ [26|25½|24½|23]

Width & Girth calculations are tuned to data obtained from
DOROTHY Mass Foot Measurement Campaign of Europe in 2010.
https://www.3dbodyscanning.org/cap/papers/2010/10338_31jurca.pdf

This script version contains eXp5™ eXp6™ & eXp7™
sizing systems which are proprietary to JSG™
See PDF documentation for liscense.

[1mMondoPoint Length, Width & Girth values are barefoot measurements.
Depending on sock thickness these can increase.[0m

End

# Prompt for output filemane.
unset fname
while :
do
	printf "\rOutput Filename <${1}> :  \b"
	read fname
	[ -n "$fname" ] && OutFile="$fname" || OutFile="$1"
	[ -n "$OutFile" ] && break
	printf "[1;31m Enter Filename <> :  \b[0m"
	sleep 1
done

# Open file handle for temporary file.
TMP=/tmp/dorothy-foot-calc_$$
if exec 3> $TMP
then
	printf "\n$TMP temporary file created.\n\n"
else
	printf "\n[1;5;31mTemp file Can NOT be created. Quitting![0m\n"
	sleep 1
	exit 1
fi

while :
do

# Column data processor.
Parse()
	{
	local cnt=0 value label

	# Gather values
	for value in $VALUES
	do
		label=${COLUMNS[$cnt]}
		case "$label" in
			    UK:)  width="$value" ;;
			    mm:) length="$value" ;;
			    in.)     in="$value" ;;
			Last.mm)   last="$value" ;;
		esac
		let cnt++
	done

	cnt=0
	echo >&3
	# Print values
	for value in $VALUES
	do
		label=${COLUMNS[$cnt]}
		[ -z "$label" ] && break
		printf "% 15b" "${label/_/ }" >&3 

		case "$label" in
			'IT|EU:') 
				case "$System" in
					      Barleycorn) value="$value  = 1¼ × [ ${length}mm ÷ 8 + ½ ] (Foot Length)" ;;
					'MondoPoint 5mm') value="$value  = 0.16 × ${length}mm (Foot Length)" ;;
					           eXp6™) value="$value  = 4.064  × $in\" (Foot Length)" ;;
					               *) value="$value  = 4  × $in\" (Foot Length)" ;;
				esac
			;;
			       CM:) value="$value  = 2⅔ × $in\" (Foot Length)" ;;
			of_Length:) value="${value}%" ;;
			    Label:) value="${value/_/ }" ;;
		esac

		echo " $value" >&3
		let cnt++
	done
	}

# Yes/No Dialog.
qYN()
	{
	local yn
	printf "$1 [y|n] : "
	read yn ; [ "$yn" = y ] && return 0 || return 1
	}

# Check Value.
ckVal()
	{
	if [ -z "$VALUES" ]
	then
		echo "	[1;5;31mEnter an Available Index Number.[0m"	

	elif [ "$VALUES" = Quit ]
	then
		eXit
	else
		break
	fi
	}

# Edit Text File.
editFile()
	{
	while :
	do
		printf "\nSelect Editor\n"

		select Ed in $EDITORS
		do
			[ -n "$Ed" ] && break
		done

		which $Ed > /dev/null 2>&1 && break
		EDITORS=${EDITORS/$Ed/}
		printf "\n  [1;31mText editor '$Ed' is not available on this system.[0m\n\n"
		sleep 1
	done

	$Ed "$1"
	echo
	}

# Create Output and Exit Clean.
eXit()
	{
	local pwd
	echo >&3 ; exec 3<&-
	[ "$1" != save ] && { rm $TMP ; exit 1 ; }

	clear ; cat $TMP
	echo

	if qYN "Create Text Output?"
	then 
		while :
		do
			unset pwd
			printf "Save  ${OutFile}.txt  in  <${PWD}> ? : "
			read  pwd

			if [ -n "$pwd" ]
			then
				if [ -d "$pwd" ] && touch ${pwd}/isWriteable 2> /dev/null
				then
					rm ${pwd}/isWriteable
					CWD="$pwd"
					break
				else
					echo "[1;5;31m	Directory not available.[0m"
				fi
			else
				CWD="$PWD"
				break
			fi
		done

		SAVE="${CWD}/${OutFile}.txt"

		if mv $TMP "$SAVE" > /dev/null 2>&1
		then
			echo "[1m      ${OutFile}.txt created.[0m"
			qYN "Edit  ${OutFile}.txt ?" && \
			{ export CWD ; editFile "$SAVE" ; }

			if qYN "Print ${OutFile}.txt to Default Printer?"
			then
				if lpr "$SAVE"
				then 
					echo "Sent to Print Queue."
				else
					echo "[1;5;31mFailed to Print.[0m"
					#sleep 1
					exit 1
				fi
			fi
		else
			echo "[1;5;31mFailed to Create Text File.[0m" >&2
			#sleep 1
			exit 1
		fi
	else
		rm $TMP > /dev/null 2>&1
	fi

	#sleep 1
	exit
	}

# Add Title.
unset Ttl ; printf "Specify document title. <${OutFile//_/ }> : "
read  Ttl ; [ -n "$Ttl" ] && Title="$Ttl" || Title="${OutFile//_/ }"
printf "\n$Title\n" >&3 ; l=${#Title} ; l=$(($l+1)) ; tildeline=`printf "% ${l}b" "\n"` ; echo ${tildeline// /\~} >&3

# Gender Selection.
printf "\n[1mSelect Gender[0m  Width & Girth Profiles\n"
select Gen in Male Female Unisex Quit
do
	if [ -z "$Gen" ]
	then
		echo "	[1;5;31mEnter a Correct Index Number.[0m"	

	elif [ "$Gen" = Quit ]
	then
		eXit
	else
		break
	fi
done

echo   "        Gender: $Gen" >&3

X5=eXp5™ ; X6=eXp6™ ; X7=eXp7™
case $Gen in
	Unisex) X5="[1meXp5™[0m" ; printf "\nUnsex profile is an average of the male & female profiles.\n" ;;
	  Male) X6="[1meXp6™[0m" ;;
    Female) X7="[1meXp7™[0m" ;;
esac

# System Selection.
printf "\n[1mSelcet Sizing System.[0m\n"
select System in Barleycorn "Paris Point" "MondoPoint 5mm" "½cm Last Inc." $X5 $X6 $X7 Quit
do
	if [ -z "$System" ]
	then
		echo "	[1;5;31mEnter a Correct Index Number.[0m"	

	elif [ "$System" = Quit ]
	then
		eXit
	else
		break
	fi
done

case $System in
	"[1meXp5™[0m") System=eXp5™ ;;
	"[1meXp6™[0m") System=eXp6™ ;;
	"[1meXp7™[0m") System=eXp7™ ;;
esac

printf "\n Sizing System: ${System}\n" >&3

##################
# Size Selection #
##################
clear
# Paris Point 3⅓mm Last Increment, Foot increment ⅛".
if [ "$System" = "Paris Point" ]
then
	COLUMNS=(BR: IT/EU: FR: Mx: UK: usM: usW: in. mm: Last.cm:)
	printf "\n          Size, 5%% Toe Room" >&3
	printf "\n[1mParis Pont Sizes, +5%% Toe Room[0m\n"
	echo "    Select Size                                         Foot Length     Last"
	echo "    $BR   $ITEU   $FR    $Mx     $UK      $usM    $usW     in.     mm      cm"

select VALUES in \
" 31     33     34      0⅖     0.9     1.9     3⅖      8¼    209.6    22" \
" 31½    33½    34½     0⅘     1.3     2.3     3⅘      8⅜    212.7    22⅓" \
" 32     34     35      1⅕     1.7     2.7     4⅕      8½    215.9    22⅔" \
" 32½    34½    35½     1⅗     2.1     3.1     4⅗      8⅝    219.1    23" \
" 33     35     36      2      2½      3½      5       8¾    222.3    23⅓" \
" 33½    35½    36½     2⅖     2.9     3.9     5⅖      8⅞    225.4    23⅔" \
" 34     36     37      2⅘     3.3     4.3     5⅘      9     228.6    24" \
" 34½    36½    37½     3⅕     3.7     4.7     6⅕      9⅛    231.8    24⅓" \
" 35     37     38      3⅗     4.1     5.1     6⅗      9¼    235.0    24⅔" \
" 35½    37½    38½     4      4½      5½      7       9⅜    238.1    25" \
" 36     38     39      4⅖     4.9     5.9     7⅖      9½    241.3    25⅓" \
" 36½    38½    39½     4⅘     5.3     6.3     7⅘      9⅝    244.5    25⅔" \
" 37     39     40      5⅕     5.7     6.7     8⅕      9¾    247.7    26" \
" 37½    39½    40½     5⅗     6.1     7.1     8⅗      9⅞    250.8    26⅓" \
" 38     40     41      6      6½      7½      9      10     254.0    26⅔" \
" 38½    40½    41½     6⅖     6.9     7.9     9⅖     10⅛    257.2    27" \
" 39     41     42      6⅘     7.3     8.3     9⅘     10¼    260.4    27⅓" \
" 39½    41½    42½     7⅕     7.7     8.7    10⅕     10⅜    263.5    27⅔" \
" 40     42     43      7⅗     8.1     9.1    10⅗     10½    266.7    28" \
" 40½    42½    43½     8      8½      9½     11      10⅝    269.9    28⅓" \
" 41     43     44      8⅖     8.9     9.9    11⅖     10¾    273.1    28⅔" \
" 41½    43½    44½     8⅘     9.3    10.3    11⅘     10⅞    276.2    29" \
" 42     44     45      9⅕     9.7    10.7    12⅕     11     279.4    29⅓" \
" 42½    44½    45½     9⅗    10.1    11.1    12⅗     11⅛    282.6    29⅔" \
" 43     45     46     10     10½     11½     13      11¼    285.8    30" \
" 43½    45½    46½    10⅖    10.9    11.9    13⅖     11⅜    288.9    30⅓" \
" 44     46     47     10⅘    11.3    12.3    13⅘     11½    292.1    30⅔" \
" 44½    46½    47½    11⅕    11.7    12.7    14⅕     11⅝    295.3    31" \
" 45     47     48     11⅗    12.1    13.1    14⅗     11¾    298.5    31⅓" \
" 45½    47½    48½    12     12½     13½     15      11⅞    301.6    31⅔" \
" 46     48     49     12⅖    12.9    13.9    15⅖     12     304.8    32" \
" 46½    48½    49½    12⅘    13.3    14.3    15⅘     12⅛    308.0    32⅓" \
" 47     49     50     13⅕    13.7    14.7    16⅕     12¼    311.2    32⅔" \
" 47½    49½    50½    13⅗    14.1    15.1    16⅗     12⅜    314.3    33" \
" 48     50     51     14     14½     15½     17      12½    317.5    33⅓" Quit
do
	ckVal
done
	Parse

# Barleycorn ~⅙" Last Increment, Foot Increment 4mm.
elif [ "$System" = Barleycorn ]
then
	COLUMNS=(Mx: UK: usM: usW: BR: IT/EU: FR: mm: in. Last.mm:)
	printf "\n          Size,5⅚%% Toe Room" >&3
	printf "\n[1mBarleycorn Sizes, +5⅚%% Toe Room[0m\n"
	echo "    Select Size                                          Foot Length"      # +6⅔%
	echo "     $Mx    $UK     $usM    $usW   $BR    $ITEU    $FR      mm     in.     Last.mm"

select VALUES in \
"  ─½     0      1      2½    29⅞     31⅞     32⅞     200     7.87     211.2" \
"  0       ½     1½     3     30½     32½     33½     204     8.03     215.5" \
"   ½     1      2      3½    31⅛     33⅛     34⅛     208     8.19     219.7" \
"  1      1½     2½     4     31¾     33¾     34¾     212     8.34     224  " \
"  1½     2      3      4½    32⅜     34⅜     35⅜     216     8.50     228.3" \
"  2      2½     3½     5     33      35      36      220     8.66     232.5" \
"  2½     3      4      5½    33⅝     35⅝     36⅝     224     8.82     236.8" \
"  3      3½     4½     6     34¼     36¼     37¼     228     8.97     241.1" \
"  3½     4      5      6½    34⅞     36⅞     37⅞     232     9.13     245⅓ " \
"  4      4½     5½     7     35½     37½     38½     236     9.29     249.6" \
"  4½     5      6      7½    36⅛     38⅛     39⅛     240     9.45     253.9" \
"  5      5½     6½     8     36¾     38¾     39¾     244     9.61     258.1" \
"  5½     6      7      8½    37⅜     39⅜     40⅜     248     9.76     262.4" \
"  6      6½     7½     9     38      40      41      252     9.92     266⅔ " \
"  6½     7      8      9½    38⅝     40⅝     41⅝     256    10.08     270.9" \
"  7      7½     8½    10     39¼     41¼     42¼     260    10.23     275.2" \
"  7½     8      9     10½    39⅞     41⅞     42⅞     264    10.39     279.5" \
"  8      8½     9½    11     40½     42½     43½     268    10.55     283.7" \
"  8½     9     10     11½    41⅛     43⅛     44⅛     272    10.71     288  " \
"  9      9½    10½    12     41¾     43¾     44¾     276    10.86     292.3" \
"  9½    10     11     12½    42⅜     44⅜     45⅜     280    11.02     296.5" \
" 10     10½    11½    13     43      45      46      284    11.18     300.8" \
" 10½    11     12     13½    43⅝     45⅝     46⅝     288    11.34     305.1" \
" 11     11½    12½    14     44¼     46¼     47¼     292    11.49     309⅓ " \
" 11½    12     13     14½    44⅞     46⅞     47⅞     296    11.65     313.6" \
" 12     12½    13½    15     45½     47½     48½     300    11.81     317.9" \
" 12½    13     14     15½    46⅛     48⅛     49⅛     304    11.97     322.1" \
" 13     13½    14½    16     46¾     48¾     49¾     308    12.12     326.4" \
" 13½    14     15     16½    47⅜     49⅜     50⅜     312    12.28     330.7" \
" 14     14½    15½    17     48      50      51      316    12.44     334.9" \
" 14½    15     16     17½    48⅝     50⅝     51⅝     320    12.60     339.2" Quit
do
	ckVal
done
	Parse

# MondoPoint 5mm Foot Increment, 5⅓mm Last Increment.
elif [ "$System" = "MondoPoint 5mm" ]
then
	COLUMNS=(mm: BR: IT/EU: FR: Mx: UK: usM: usW: in. Last.mm:)
	printf "\n          Size, 6⅔%% Toe Room" >&3
	printf "\n[1mMondoPoint Sizes, +6⅔%% Toe Room[0m\n"
	echo "    Select Size                                                  Foot Length"
	echo "      [1mMM[0m    $BR   $ITEU    $FR     $Mx      $UK      $usM     $usW     in.   Last.mm"

select VALUES in \
" 205    30.8    32.8    33.8     0.2     0.7     1.7     3.2     8.07    218⅔" \
" 210    31.6    33.6    34.6     0.9     1.4     2.4     3.9     8.27    224 " \
" 215    32.4    34.4    35.4     1.5     2.0     3.0     4.5     8.46    229⅓" \
" 220    33.2    35.2    36.2     2.2     2.7     3.7     5.2     8.66    234⅔" \
" 225    34.0    36.0    37.0     2.8     3.3     4.3     5.8     8.86    240 " \
" 230    34.8    36.8    37.8     3.4     3.9     4.9     6.4     9.06    245⅓" \
" 235    35.6    37.6    38.6     4.1     4.6     5.6     7.1     9.25    250⅔" \
" 240    36.4    38.4    39.4     4.7     5.2     6.2     7.7     9.45    256 " \
" 245    37.2    39.2    40.2     5.4     5.9     6.9     8.4     9.65    261⅓" \
" 250    38.0    40.0    41.0     6.0     6.5     7.5     9.0     9.84    266⅔" \
" 255    38.8    40.8    41.8     6.6     7.1     8.1     9.6    10.04    272 " \
" 260    39.6    41.6    42.6     7.3     7.8     8.8    10.3    10.24    277⅓" \
" 265    40.4    42.4    43.4     7.9     8.4     9.4    10.9    10.43    282⅔" \
" 270    41.2    43.2    44.2     8.6     9.1    10.1    11.6    10.63    288 " \
" 275    42.0    44.0    45.0     9.2     9.7    10.7    12.2    10.83    293⅓" \
" 280    42.8    44.8    45.8     9.8    10.3    11.3    12.8    11.02    298⅔" \
" 285    43.6    45.6    46.6    10.5    11.0    12.0    13.5    11.22    304 " \
" 290    44.4    46.4    47.4    11.1    11.6    12.6    14.1    11.42    309⅓" \
" 295    45.2    47.2    48.2    11.8    12.3    13.3    14.8    11.61    314⅔" \
" 300    46.0    48.0    49.0    12.4    12.9    13.9    15.4    11.81    320 " \
" 305    46.8    48.8    49.8    13.0    13.5    14.5    16.0    12.01    325⅓" \
" 310    47.6    49.6    50.6    13.7    14.2    15.2    16.7    12.20    330⅔" \
" 315    48.4    50.4    51.4    14.3    14.8    15.8    17.3    12.40    336 " \
" 320    49.2    51.2    52.2    15.0    15.5    16.5    18.0    12.60    341⅓" Quit
do
	ckVal
done
	Parse

# ½ Centimeter Last Increment, ³/₁₆" Foot Increment.
elif [ "$System" = "½cm Last Inc." ]
then
	COLUMNS=(CM: BR: IT/EU: FR: Mx: UK: usM: usW: in. mm:)
	printf "\n          Size, 5%% Toe Room" >&3
	printf "\n[1m½ Centimeter Sizes, +5%% Toe Room[0m\n"
	echo "    Select Size                                                     Foot Length"
	echo "     [1mCM[0m    $BR   $ITEU   $FR     $Mx     $UK      $usM     $usW      in.        mm"

select VALUES in \
" 22     31     33     34      0.4     0.9     1.9     3.4      8 ¼       209.6" \
" 22½    31¾    33¾    34¾     1.0     1.5     2.5     4.0      8 ⁷/₁₆    214.3" \
" 23     32½    34½    35½     1.6     2.1     3.1     4.6      8 ⅝       219.1" \
" 23½    33¼    35¼    36¼     2.2     2.7     3.7     5.2      8¹³/₁₆    223.8" \
" 24     34     36     37      2.8     3.3     4.3     5.8      9         228.6" \
" 24½    34¾    36¾    37¾     3.4     3.9     4.9     6.4      9 ³/₁₆    233.4" \
" 25     35½    37½    38½     4.0     4.5     5.5     7.0      9 ⅜       238.1" \
" 25½    36¼    38¼    39¼     4.6     5.1     6.1     7.6      9 ⁹/₁₆    242.9" \
" 26     37     39     40      5.2     5.7     6.7     8.2      9 ¾       247.7" \
" 26½    37¾    39¾    40¾     5.8     6.3     7.3     8.8      9¹⁵/₁₆    252.4" \
" 27     38½    40½    41½     6.4     6.9     7.9     9.4     10 ⅛       257.2" \
" 27½    39¼    41¼    42¼     7.0     7.5     8.5    10.0     10 ⁵/₁₆    261.9" \
" 28     40     42     43      7.6     8.1     9.1    10.6     10 ½       266.7" \
" 28½    40¾    42¾    43¾     8.2     8.7     9.7    11.2     10¹¹/₁₆    271.5" \
" 29     41½    43½    44½     8.8     9.3    10.3    11.8     10 ⅞       276.2" \
" 29½    42¼    44¼    45¼     9.4     9.9    10.9    12.4     11 ¹/₁₆    281.0" \
" 30     43     45     46     10.0    10.5    11.5    13.0     11 ¼       285.8" \
" 30½    43¾    45¾    46¾    10.6    11.1    12.1    13.6     11 ⁷/₁₆    290.5" \
" 31     44½    46½    47½    11.2    11.7    12.7    14.2     11 ⅝       295.3" \
" 31½    45¼    47¼    48¼    11.8    12.3    13.3    14.8     11¹³/₁₆    300.0" \
" 32     46     48     49     12.4    12.9    13.9    15.4     12         304.8" \
" 32½    46¾    48¾    49¾    13.0    13.5    14.5    16.0     12 ³/₁₆    309.6" \
" 33     47½    49½    50½    13.6    14.1    15.1    16.6     12 ⅜       314.3" \
" 33½    48¼    50¼    51¼    14.2    14.7    15.7    17.2     12 ⁹/₁₆    319.1" Quit
do
	ckVal
done
	Parse

# Unisex eXponential Foot Increment.
elif [ "$System" = "eXp5™" ]
then
	COLUMNS=(eXp5: UK: usM: usW: IT/EU: in. mm: Last.mm:)
	printf "\n          Size, 6⅔%% Toe Room" >&3
	printf "\n[1m $eXp5 eXponential Sizes, +6⅔%% Toe Room[0m\n"
	echo "    Select Size                                 Foot Length      Last"
	echo "    $eXp5    $UK       $usM      $usW    $ITEU     in.      mm       mm"

select VALUES in \
" 7★0     1.41     2.41     3.91    33.5     8.25    209.6    223.6" \
" 7★1     1.93     2.93     4.43    34.2     8.42    213.7    228.0" \
" 7★2     2.46     3.46     4.96    34.9     8.58    218.0    232.5" \
" 7★3     3.01     4.01     5.51    35.5     8.75    222.3    237.1" \
" 7★4     3.56     4.56     6.06    36.2     8.92    226.7    241.8" \
" 7★5     4.13     5.13     6.63    37.0     9.10    231.2    246.6" \
" 7★6     4.70     5.70     7.20    37.7     9.28    235.8    251.5" \
" 7★7     5.29     6.29     7.79    38.4     9.47    240.4    256.5" \
" 7★8     5.89     6.89     8.39    39.2     9.65    245.2    261.5" \
" 7★9     6.50     7.50     9.00    40.0     9.84    250.0    266.7" \
" 8★0     7.13     8.13     9.63    40.8    10.04    255.0    272.0" \
" 8★1     7.76     8.76    10.26    41.6    10.24    260.0    277.4" \
" 8★2     8.41     9.41    10.91    42.4    10.44    265.2    282.9" \
" 8★3     9.07    10.07    11.57    43.2    10.65    270.5    288.5" \
" 8★4     9.75    10.75    12.25    44.1    10.86    275.8    294.2" \
" 8★5    10.44    11.44    12.94    45.0    11.07    281.3    300.0" \
" 8★6    11.14    12.14    13.64    45.9    11.29    286.8    306.0" \
" 8★7    11.85    12.85    14.35    46.8    11.52    292.5    312.0" \
" 8★8    12.58    13.58    15.08    47.7    11.74    298.3    318.2" \
" 8★9    13.33    14.33    15.83    48.7    11.98    304.2    324.5" \
" 9★0    14.09    15.09    16.59    49.6    12.21    310.2    330.9" \
" 9★1    14.86    15.86    17.36    50.6    12.46    316.4    337.5" \
" 9★2    15.65    16.65    18.15    51.6    12.70    322.7    344.2" \
" 9★3    16.45    17.45    18.95    52.6    12.95    329.0    351.0" \
" 9★4    17.28    18.28    19.78    53.7    13.21    335.6    357.9" \
" 9★5    18.11    19.11    20.61    54.7    13.47    342.2    365.0" Quit
do
	ckVal
done
	Parse

# eXponential 6 Foot Increment.
elif [ "$System" = "eXp6™" ]
then
	COLUMNS=(eXp6: UK: usM: usW: IT/EU: in. mm: Last.mm:)
	printf "\n          Size, 6⅔%% Toe Room" >&3
	printf "\n[1m $eXp6 eXponential Sizes, +6⅔%% Toe Room[0m\n"
	echo "    Select Size                                 Foot Length      Last"
	echo "    $eXp6    $UK       $usM      $usW    $ITEU     in.      mm       mm"

select VALUES in \
" 7✶0     2.23     3.23     4.73    34.6     8.51    216.1    230.6" \
" 7✶1     2.67     3.67     5.17    35.1     8.65    219.7    234.3" \
" 7✶2     3.12     4.12     5.62    35.7     8.79    223.2    238.1" \
" 7✶3     3.58     4.58     6.08    36.3     8.93    226.8    242.0" \
" 7✶4     4.05     5.05     6.55    36.9     9.07    230.5    245.9" \
" 7✶5     4.52     5.52     7.02    37.5     9.22    234.3    249.9" \
" 7✶6     5.00     6.00     7.50    38.1     9.38    238.1    254.0" \
" 7✶7     5.49     6.49     7.99    38.7     9.53    242.0    258.1" \
" 7✶8     5.98     6.98     8.48    39.3     9.68    245.9    262.3" \
" 7✶9     6.49     7.49     8.99    40.0     9.84    249.9    266.6" \
" 8✶0     7.00     8.00     9.50    40.6    10.00    254.0    270.9" \
" 8✶1     7.52     8.52    10.02    41.3    10.16    258.1    275.3" \
" 8✶2     8.05     9.05    10.55    41.9    10.33    262.3    279.8" \
" 8✶3     8.59     9.59    11.09    42.6    10.50    266.6    284.4" \
" 8✶4     9.13    10.13    11.63    43.3    10.67    270.9    289.0" \
" 8✶5     9.69    10.69    12.19    44.0    10.84    275.3    293.7" \
" 8✶6    10.25    11.25    12.75    44.7    11.02    279.8    298.5" \
" 8✶7    10.83    11.83    13.33    45.5    11.20    284.4    303.3" \
" 8✶8    11.41    12.41    13.91    46.2    11.38    289.0    308.3" \
" 8✶9    12.00    13.00    14.50    47.0    11.56    293.7    313.3" \
" 9✶0    12.60    13.60    15.10    47.7    11.75    298.5    318.4" \
" 9✶1    13.21    14.21    15.71    48.5    11.94    303.3    323.6" \
" 9✶2    13.84    14.84    16.34    49.3    12.14    308.3    328.8" \
" 9✶3    14.47    15.47    16.97    50.1    12.33    313.3    334.2" \
" 9✶4    15.11    16.11    17.61    50.9    12.53    318.4    339.6" \
" 9✶5    15.76    16.76    18.26    51.7    12.74    323.6    345.1" Quit
do
	ckVal
done
	Parse

# Women's eXponential Foot Increment.
elif [ "$System" = "eXp7™" ]
then
	COLUMNS=(eXp7: UK: usM: usW: IT/EU: in. mm: Last.mm:)
	printf "\n          Size, 5%% Toe Room" >&3
	printf "\n[1m $eXp7 eXponontial Sizes, +5%% Toe Room[0m\n"
	echo "    Select Size                        Foot Length      Last"
	echo "    $eXp7     $UK      $usM      $usW    $ITEU     in.      mm       mm"

select VALUES in \
" 7⧗0     2.56     3.56     5.06    35.0     8.75    222.2    233.3" \
" 7⧗1     2.93     3.93     5.43    35.4     8.87    225.2    236.5" \
" 7⧗2     3.30     4.30     5.80    35.9     8.99    228.3    239.6" \
" 7⧗3     3.69     4.69     6.19    36.4     9.11    231.3    242.9" \
" 7⧗4     4.07     5.07     6.57    36.9     9.23    234.4    246.1" \
" 7⧗5     4.46     5.46     6.96    37.4     9.35    237.6    249.4" \
" 7⧗6     4.86     5.86     7.36    37.9     9.48    240.8    252.8" \
" 7⧗7     5.26     6.26     7.76    38.4     9.61    244.0    256.2" \
" 7⧗8     5.67     6.67     8.17    38.9     9.74    247.3    259.6" \
" 7⧗9     6.08     7.08     8.58    39.4     9.87    250.6    263.1" \
" 8⧗0     6.50     7.50     9.00    40.0    10.00    254.0    266.7" \
" 8⧗1     6.92     7.92     9.42    40.5    10.13    257.4    270.3" \
" 8⧗2     7.35     8.35     9.85    41.1    10.27    260.9    273.9" \
" 8⧗3     7.78     8.78    10.28    41.6    10.41    264.4    277.6" \
" 8⧗4     8.22     9.22    10.72    42.2    10.55    267.9    281.3" \
" 8⧗5     8.67     9.67    11.17    42.7    10.69    271.5    285.1" \
" 8⧗6     9.12    10.12    11.62    43.3    10.83    275.2    288.9" \
" 8⧗7     9.58    10.58    12.08    43.9    10.98    278.9    292.8" \
" 8⧗8    10.05    11.05    12.55    44.5    11.13    282.6    296.7" \
" 8⧗9    10.52    11.52    13.02    45.1    11.28    286.4    300.7" \
" 9⧗0    11.00    12.00    13.50    45.7    11.43    290.3    304.8" Quit
do
	ckVal
done
	Parse

else
	exec 3<&- ; rm $TMP > /dev/null 2>&1 ; exit 1
fi

###################
# Widths & Girths #
###################

# Width & Girth Parameters.
# WIDTH|GIRTH % of Length: .#### Tangent & _BIAS: ##.## mm.
case $Gen in
	Male) # A    B    C    D    E    F    G    H    I    J    K
	WIDTH=(2297 2364 2433 2504 2577 2652 2730 2809 2891 2976 3063)
	WBIAS=(2682 2761 2841 2924 3009 3097 3188 3281 3376 3475 3576)
	GIRTH=(5815 5965 6119 6277 6439 6605 6775 6950 7129 7313 7502)
	GBIAS=(7035 7216 7402 7593 7789 7990 8196 8407 8624 8847 9075)
	;;
	Unisex)
	WIDTH=(2795 2876 2960 3047 3136 3227 3321 3418 3518 3621 3727)
	WBIAS=(1275 1313 1351 1390 1431 1473 1516 1560 1605 1652 1701)
	GIRTH=(7515 7715 7920 8130 8346 8568 8796 9030 9270 9516 9769)
	GBIAS=(2264 2325 2386 2450 2515 2582 2650 2721 2793 2867 2944)
	;;
	Female)
	WIDTH=(2529 2603 2679 2757 2838 2921 3006 3094 3184 3277 3372)
	WBIAS=(1938 1995 2053 2113 2175 2238 2304 2371 2440 2511 2585)
	GIRTH=(5528 5670 5817 5967 6121 6279 6440 6607 6777 6952 7131)
	GBIAS=(7188 7374 7564 7759 7959 8164 8375 8591 8813 9040 9273)
	;;
esac

# Calculate Width & Girth.
[ ${#length} -gt 3 ] && l=${length/./} || l="${length}0"
cnt=0
for L in {A..K}
do
	 w=${WIDTH[$cnt]}
	ow=${WBIAS[$cnt]}
	 g=${GIRTH[$cnt]}
	og=${GBIAS[$cnt]}

	w=$((  $w * $l + ${ow}000 ))
	p=$(( ($w / $l + 5) / 10 ))
	p=${p:0:2}.${p:2:1}
	w=$(( ($w / 1000 + 5) / 10 ))
	g=$((  $g * $l + ${og}000 ))
	r=$(($g / $w ))
	g=$(( ($g / 1000 + 5) / 10 ))
	r=$(( ($r + 5) / 10 ))

	eval  $L=\$p
	eval w$L=\$w
	eval g$L=\$g
	eval r$L=\$r
	 let cnt++
done

N=$C ; M=$E ; W=$G ; X=$I
# Width Selection.
clear
COLUMNS=(of_Length: US: UK: Label: Alt.)
printf "\n[1mShoe Widths[0m\n"
echo "Select Width (Percent of Foot Length)"
echo "    Percent      $US      $UK        Label       Alt."

select VALUES in \
" $A       AAA       A       X_Slim         I                           " \
" $B        AA       B         Slim        II                           " \
" $C         A       C       Narrow       III                           " \
" $D         B       D       MedNar        IV                           " \
" $E         C       E       Medium         V                           " \
" $F         D       F       MedWid        VI                           " \
" $G         E       G         Wide       VII                           " \
" $H        EE       H       X_Wide      VIII                           " \
" $I       EEE       I      2X_Wide        IX                           " \
" $J        4E       J      3X_Wide         X                           " \
" $K        5E       K      4X_Wide        XI                           " \
" $N       Nar       N       Narrow       III                           " \
" $M       Med       M       Mediun         V                           " \
" $W       Wid       W         Wide       VII                           " \
" $X       2XW       X      2X_Wide        IX                           " \
" Quit                                                                  "
do
	if [ -z "$VALUES" ]
	then
		echo "	[1;5;31mEnter an Available Index Number.[0m"	

	elif [ "${VALUES:1:4}" = Quit ]
	then
		eXit save
	else
		break
	fi
done

printf "\n         Width" >&3

Parse

# Set Width & Girth.
case $width in
	A) w=$wA ; g=$gA ; r=$rA ;; B) w=$wB ; g=$gB ; r=$rB ;; C) w=$wC ; g=$gC ; r=$rC  ;;
	D) w=$wD ; g=$gD ; r=$rD ;; E) w=$wE ; g=$gE ; r=$rE ;; F) w=$wF ; g=$gF ; r=$rF  ;;
	G) w=$wG ; g=$gG ; r=$rG ;; H) w=$wH ; g=$gH ; r=$rH ;; I) w=$wI ; g=$gI ; r=$rI  ;;
	J) w=$wJ ; g=$gJ ; r=$rJ ;; K) w=$wK ; g=$gK ; r=$rK ;; N) w=$wC ; g=$gC ; r=$rC  ;;
	M) w=$wE ; g=$gE ; r=$rE ;; W) w=$wG ; g=$gG ; r=$rG ;; X) w=$wI ; g=$gI ; r=$rI  ;;
esac

# Print MondoPoint Length, Width, and Girth Values.
c=$(( ${#w} - 1 ))
printf "\n    MondoPoint (Weight Bearing)\n" >&3
echo     "        Length: ${l:0:3}.${l:3:1} mm" >&3
printf   "         Width: " >&3 ; printf "% 9b" "${w:0:$c}.${w:$c:1} mm\n" >&3
echo     "         Girth: ${g:0:3}.${g:3:1} mm" >&3 
echo     "     G÷W Ratio:   ${r:0:1}.${r:1:4}" >&3 

if qYN "All OK?"
then
	break
else
	qYN "Redo?" || eXit
	exec 3<&- ; rm $TMP ; exec 3> $TMP
fi

done

# Add Notes.
if qYN "Add any Notes?"
then
	printf "\nNOTE: To End use Ctrl-D on a New Line.\n\n"
	printf "\nNotes:\n" >&3
	cat >&3
fi

eXit save
exit 1

